__all__ = ('ScoringMTSPoint',)

from expressmoney_service.api import *

_SERVICE = 'services'


class ScoringMTSCreateContract(Contract):
    phone_number = serializers.CharField()


class ScoringMTSResponseContract(Contract):
    score = serializers.FloatField()


class ScoringMTSID(ID):
    _service = _SERVICE
    _app = 'scoring_mts'
    _view_set = 'scoring'


class ScoringMTSPoint(CreatePointMixin, ResponseMixin, ContractPoint):
    _point_id = ScoringMTSID()
    _create_contract = ScoringMTSCreateContract
    _response_contract = ScoringMTSResponseContract



__all__ = ('ValidateAddressPoint', 'UpdateAddressPoint')

from ..api import *

_SERVICE = 'services'

EMPTY = 'EMPTY'
SUCCESS = 'SCS'
FAILURE = 'FAIL'

RESULT_CHOICES = (
    (EMPTY, EMPTY),
    (FAILURE, FAILURE),
    (SUCCESS, SUCCESS),
)


class ValidateAddressCreateContract(Contract):
    address = serializers.CharField(max_length=256)


class ValidateAddressResponseContract(Contract):
    result = serializers.ChoiceField(choices=RESULT_CHOICES)
    data = serializers.JSONField(allow_null=True)

class UpdateAddressCreateContract(Contract):
    xml_name = serializers.CharField(max_length=256)


class _ValidateAddress(ID):
    _service = _SERVICE
    _app = 'da_data'
    _view_set = 'validate_address'

class _UpdateAddressID(ID):
    _service = _SERVICE
    _app = 'da_data'
    _view_set = 'update_address'


class ValidateAddressPoint(CreatePointMixin, ResponseMixin, ContractPoint):
    _point_id = _ValidateAddress()
    _create_contract = ValidateAddressCreateContract
    _response_contract = ValidateAddressResponseContract

class UpdateAddressPoint(CreatePointMixin, ContractPoint):
    _point_id = _UpdateAddressID()
    _create_contract = UpdateAddressCreateContract



__all__ = ('PassportReaderPoint',)

from ..api import *

_SERVICE = 'services'
_APP = 'smart_id_reader'

EMPTY = 'EMPTY'
SUCCESS = 'SCS'
FAILURE = 'FAIL'

RESULT_CHOICES = (
    (EMPTY, EMPTY),
    (FAILURE, FAILURE),
    (SUCCESS, SUCCESS),
)


class PassportReaderCreateContract(Contract):
    file = serializers.FileField()


class PassportReaderResponseContract(Contract):
    result = serializers.ChoiceField(choices=RESULT_CHOICES)
    data = serializers.JSONField(allow_null=True)


class _PassportReader(ID):
    _service = _SERVICE
    _app = _APP
    _view_set = 'passport_reader'


class PassportReaderPoint(UploadFilePointMixin, ResponseMixin, ContractPoint):
    _point_id = _PassportReader()
    _create_contract = PassportReaderCreateContract
    _response_contract = PassportReaderResponseContract



__all__ = ('ScoringNBKIPoint',)

from expressmoney_service.api import *

_SERVICE = 'services'


class ScoringNBKICreateContract(Contract):
    MS9N = 'MS9N'
    MODEL_TYPE = (
        (MS9N, MS9N),
    )

    first_name = serializers.CharField(max_length=32)
    last_name = serializers.CharField(max_length=32)
    middle_name = serializers.CharField(max_length=32)
    birth_date = serializers.DateField()
    passport_serial = serializers.CharField(max_length=4)
    passport_number = serializers.CharField(max_length=6)
    passport_code = serializers.CharField(max_length=16)
    passport_date = serializers.DateField()
    snils = serializers.CharField(max_length=64, null=True)
    phone_number = serializers.CharField()
    model_code = serializers.CharField(max_length=8, choices=MODEL_TYPE)


class ScoringNBKIResponseContract(Contract):
    score = serializers.FloatField()


class ScoringMTSID(ID):
    _service = _SERVICE
    _app = 'scoring_nbki'
    _view_set = 'scoring'


class ScoringNBKIPoint(CreatePointMixin, ResponseMixin, ContractPoint):
    _point_id = ScoringMTSID()
    _create_contract = ScoringNBKICreateContract
    _response_contract = ScoringNBKIResponseContract



__all__ = ('RuVerificatorPoint',)

from expressmoney_service.api import *
from phonenumber_field.serializerfields import PhoneNumberField

_SERVICE = 'services'


class RuVerificatorId(ID):
    _service = _SERVICE
    _app = "ru_verificator"
    _view_set = "verification_init"


class RuVerificatorCreateContract(Contract):
    user_id = serializers.IntegerField()
    phonenumber = PhoneNumberField(allow_null=True)
    first_name = serializers.CharField(max_length=32)
    last_name = serializers.CharField(max_length=32)
    middle_name = serializers.CharField(max_length=32)
    birthdate = serializers.DateField(allow_null=True)
    passport_serial = serializers.CharField(max_length=4)
    passport_number = serializers.CharField(max_length=6)
    passport_code = serializers.CharField(max_length=16, help_text='Government department code')
    passport_date = serializers.DateField(allow_null=True)


class RuVerificatorPoint(CreatePointMixin, ContractPoint):
    _point_id = RuVerificatorId()
    _create_contract = RuVerificatorCreateContract



__all__ = ('ScoringBeeLinePoint',)

from phonenumber_field.serializerfields import PhoneNumberField

from expressmoney_service.api import *

_SERVICE = 'services'


class ScoringBeeLineCreateContract(Contract):
    phone_number = PhoneNumberField()


class ScoringBeeLineResponseContract(Contract):
    score = serializers.FloatField()


class ScoringBeeLineID(ID):
    _service = _SERVICE
    _app = 'scoring_beeline'
    _view_set = 'score'


class ScoringBeeLinePoint(CreatePointMixin, ResponseMixin, ContractPoint):
    _point_id = ScoringBeeLineID()
    _create_contract = ScoringBeeLineCreateContract
    _response_contract = ScoringBeeLineResponseContract



__all__ = ('Tele2Point',)

from phonenumber_field.serializerfields import PhoneNumberField

from expressmoney_service.api import *

_SERVICE = 'services'
_APP = 'tele2'

EMPTY = 'EMPTY'
SUCCESS = 'SCS'
FAILURE = 'FAIL'

RESULT_CHOICES = (
    (EMPTY, EMPTY),
    (FAILURE, FAILURE),
    (SUCCESS, SUCCESS),
)


class _Tele2CreateContract(Contract):
    username = serializers.CharField()
    first_name = serializers.CharField(max_length=32)
    last_name = serializers.CharField(max_length=32)
    middle_name = serializers.CharField(max_length=32, allow_blank=True)
    doc_series = serializers.CharField(max_length=4)
    doc_number = serializers.CharField(max_length=6)
    birth_date = serializers.DateField()


class _Tele2ResponseContract(Contract):
    result = serializers.ChoiceField(choices=RESULT_CHOICES)
    comment = serializers.CharField(max_length=256)


class _Tele2ID(ID):
    _service = _SERVICE
    _app = _APP
    _view_set = 'verification'


class Tele2Point(CreatePointMixin, ResponseMixin,ContractPoint):
    _point_id = _Tele2ID()
    _create_contract = _Tele2CreateContract
    _response_contract = _Tele2ResponseContract



__all__ = ('NoLoanPoint', 'SmsPoint', 'CourtAddressPoint',)

from phonenumber_field.serializerfields import PhoneNumberField

from expressmoney_service.api import *

_SERVICE = 'services'
_APP = 'server1c'


class _NoLoanCreateContract(Contract):
    passport_serial = serializers.CharField(max_length=4)
    passport_number = serializers.CharField(max_length=6)


class _SmsCreateContract(Contract):
    phonenumber = PhoneNumberField()
    message = serializers.CharField(max_length=60)


class _CourtAddressCreateContract(Contract):
    address = serializers.CharField(max_length=256)
    region_fias_id = serializers.CharField(max_length=64, allow_blank=True)


class _CourtAddressResponseContract(Contract):
    court_address = serializers.CharField(max_length=256)
    region_name = serializers.CharField(max_length=128)


class _NoLoanID(ID):
    _service = _SERVICE
    _app = _APP
    _view_set = 'no_loan'


class _SmsID(ID):
    _service = _SERVICE
    _app = _APP
    _view_set = 'sms'


class CourtAddressID(ID):
    _service = _SERVICE
    _app = _APP
    _view_set = 'court_address'


class NoLoanPoint(CreatePointMixin, ContractPoint):
    _point_id = _NoLoanID()
    _create_contract = _NoLoanCreateContract


class SmsPoint(CreatePointMixin, ContractPoint):
    _point_id = _SmsID()
    _create_contract = _SmsCreateContract


class CourtAddressPoint(ResponseMixin, CreatePointMixin, ContractPoint):
    _point_id = CourtAddressID()
    _create_contract = _CourtAddressCreateContract
    _response_contract = _CourtAddressResponseContract



"""
py setup.py sdist
twine upload dist/expressmoney-service-1.3.12.tar.gz
"""
import setuptools

setuptools.setup(
    name='expressmoney-service',
    packages=setuptools.find_packages(),
    version='1.3.12',
    description='Remote services',
    author='Development team',
    author_email='dev@expressmoney.com',
    install_requires=('expressmoney', 'django-phonenumber-field[phonenumberslite]'),
    python_requires='>=3.7',
)
